import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range([50, 30]);

export const fruitCircles = dependencies => {
  const {
    selection,
    fruits,
    height,
    onHover,
    hoveredIndex
  } = dependencies;

  const circles = selection
    .selectAll('circle').data(fruits);
  circles.enter().append('circle')
    .merge(circles)
      .attr('cx', (d, i) => i * 120 + 60)
      .attr('cy', height / 2)
      .attr('fill', d => colorScale(d.type))
      .attr('stroke-width', 5)
      .attr('stroke', (d, i) =>
        i === hoveredIndex ? 'black' : 'none'
      )
      .attr('r', d => radiusScale(d.type))
      .on('mouseover', (d, i) => onHover(i))
      .on('mouseout', () => onHover(null));
  circles.exit().remove();
};

fruitCircles.dependencies = `
  selection,
  fruits,
  height,
  onHover,
  hoveredIndex
`;